@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::ARODLAND;
 # ABSTRACT: Use L<Dist::Zilla> like ARODLAND does
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 use 5.10.0;
 use Moose;
@@ -147,17 +147,19 @@ sub bundle_config {
       }
     ],
     [
-      GatherDir => {
-      }
+      GatherDir => { }
     ],
     ($install_plugin eq 'modulebuild_optionalxs'
-      ? ([ 'ModuleBuild::OptionalXS' => [] ])
+      ? ([ 'ModuleBuild::OptionalXS' => { } ])
       : ()
     ),
     ($install_plugin eq 'mbtiny'
-      ? ([ 'ModuleBuildTiny' => [] ])
+      ? ([ 'ModuleBuildTiny' => { } ])
       : ()
     ),
+    [
+      MetaJSON => { }
+    ],
 #    [ CheckChangesHasContent => { } ],
   );
 
@@ -220,7 +222,7 @@ Dist::Zilla::PluginBundle::ARODLAND - Use L<Dist::Zilla> like ARODLAND does
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 DESCRIPTION
 
@@ -290,6 +292,8 @@ It's equvalent to
 
     [ModuleBuild::OptionalXS] ;; if install_plugin is 'modulebuild_optionalxs'
 
+    [MetaJSON]
+
     [@Git]
     allow_dirty = dist.ini
     allow_dirty = README
